<div align="center">
  <img src="https://storage.googleapis.com/hume-public-logos/covcheck/covcheck-dino-banner.png">
  <h1>covcheck</h1>

  <p>
    <strong>Command-line tool for code coverage validation</strong>
  </p>

  <br>
  <div>
    <a href="https://badge.fury.io/py/covcheck"><img src="https://badge.fury.io/py/covcheck.svg" alt="PyPI"></a>
    <a href="https://pepy.tech/project/covcheck"><img src="https://pepy.tech/badge/covcheck" alt="Downloads"></a>
    <a href="https://github.com/HumeAI/covcheck/actions/workflows/ci.yml"><img src="https://github.com/HumeAI/covcheck/actions/workflows/ci.yaml/badge.svg" alt="CI"></a>
  </div>
  <br>
</div>

## About

`covcheck` is intended to be used in conjunction with [coverage.py](https://coverage.readthedocs.io/), which already has support for `pytest`, `unittest`, and `nosetest`. All you have to do is point `covcheck` to the `coverage.xml` file produced when running your tests.

For more information on how to use `covcheck` please check out the [official docs page](https://humeai.github.io/covcheck).
